import Octokit from '@octokit/rest';
import { ICommit } from 'gitlog';
import { ILabelDefinition } from './release';
import { ILogger } from './utils/logger';
declare type Omit<T, K extends keyof T> = Pick<T, Exclude<keyof T, K>> & Partial<Pick<T, K>>;
export declare type IPRInfo = Omit<Octokit.ReposCreateStatusParams, 'owner' | 'repo'>;
export interface IGitOptions {
    owner: string;
    repo: string;
    baseUrl?: string;
    graphqlBaseUrl?: string;
    token?: string;
}
export default class Git {
    readonly options: IGitOptions;
    private readonly baseUrl;
    private readonly graphqlBaseUrl;
    private readonly ghub;
    private readonly logger;
    constructor(options: IGitOptions, logger?: ILogger);
    getLatestReleaseInfo(): Promise<Octokit.ReposGetLatestReleaseResponse>;
    getLatestRelease(): Promise<string>;
    getCommitDate(sha: string): Promise<string>;
    getFirstCommit(): Promise<string>;
    /**
     * Get the SHA of the latest commit
     */
    getSha(short?: boolean): Promise<string>;
    getLabels(prNumber: number): Promise<string[]>;
    getProjectLabels(): Promise<string[]>;
    getGitLog(start: string, end?: string): Promise<ICommit[]>;
    getUserByEmail(email: string): Promise<any>;
    getUserByUsername(username: string): Promise<Octokit.UsersGetByUsernameResponse>;
    getPullRequest(pr: number): Promise<Octokit.Response<Octokit.PullsGetResponse>>;
    searchRepo(options: Octokit.SearchIssuesAndPullRequestsParams): Promise<any>;
    graphql(query: string): Promise<any>;
    createStatus(prInfo: IPRInfo): Promise<Octokit.Response<Octokit.ReposCreateStatusResponse>>;
    createLabel(name: string, label: ILabelDefinition): Promise<Octokit.Response<Octokit.IssuesCreateLabelResponse>>;
    updateLabel(name: string, label: ILabelDefinition): Promise<Octokit.Response<Octokit.IssuesUpdateLabelResponse>>;
    addLabelToPr(pr: number, label: string): Promise<Octokit.Response<Octokit.IssuesAddLabelsResponseItem[]>>;
    lockIssue(issue: number): Promise<Octokit.Response<Octokit.IssuesLockResponse>>;
    getProject(): Promise<Octokit.ReposGetResponse>;
    getPullRequests(options?: Partial<Octokit.PullsListParams>): Promise<Octokit.PullsListResponseItem[]>;
    getCommitsForPR(pr: number): Promise<Octokit.PullsListCommitsResponseItem[]>;
    createComment(message: string, pr: number, context?: string): Promise<Octokit.Response<Octokit.IssuesCreateCommentResponse>>;
    publish(releaseNotes: string, tag: string): Promise<Octokit.Response<Octokit.ReposCreateReleaseResponse>>;
}
export {};
